#
# spec file for package borgbackup
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2016-2024 LISA GmbH, Bingen, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# define variables needed to build/install borgbackup >= 1.2.0
%define borg_openssl_prefix BORG_OPENSSL_PREFIX=%{_prefix}/lib:%{_libdir}
# needed when building without the packaged algorithms
%define borg_liblz4_prefix BORG_LIBLZ4_PREFIX=%{_includedir}
%define borg_libzstd_prefix BORG_LIBZSTD_PREFIX=%{_includedir}
# new defintion needed with borgbackup >= 1.4.0
%define borg_libxxhash_prefix BORG_LIBXXHASH_PREFIX=%{_includedir}
%define borg_libacl_prefix BORG_LIBACL_PREFIX=%{_includedir}
%if 0%{?suse_version} >= 1500
# use new compression libs (lz4, zstd)
%bcond_without  borg_newcompr
# run tests (may fail without former conditionals)
%bcond_without  borg_test
# use sphinx guzzle theme
%bcond_without  borg_guzzle
%else
%bcond_with     borg_newcompr
%bcond_with     borg_test
%bcond_with     borg_guzzle
%endif
# libb2 is available since Leap 15.2
%if ( 0%{?sle_version} >= 150200 && 0%{?is_opensuse} ) || ( 0%{?suse_version} > 1500 )
%bcond_without	borg_sysblake2
%else
%bcond_with     borg_sysblake2
%endif
Name:           borgbackup
Version:        1.4.0
Release:        1.4
Summary:        Deduplicating backup program with compression and authenticated encryption
License:        BSD-3-Clause
Group:          Productivity/Archiving/Backup
URL:            https://github.com/borgbackup/borg
Source0:        https://github.com/borgbackup/borg/releases/download/%{version}/borgbackup-%{version}.tar.gz
Source1:        https://github.com/borgbackup/borg/releases/download/%{version}/borgbackup-%{version}.tar.gz.asc
Source2:        %{name}.keyring
# PATCH-FIX-OPENSUSE borgbackup-1.1.4-sphinx-default-theme.patch <hpj@urpla.net>
# python3-guzzle_sphinx_theme isn't available everywhere,
# fall back to Sphinx default theme for older distributions
Patch0:         borgbackup-1.1.4-sphinx-default-theme.patch
# SECTION build dependencies
BuildRequires:  bash
BuildRequires:  fdupes
BuildRequires:  fish
BuildRequires:  gcc-c++
BuildRequires:  libacl-devel >= 2.2.47
BuildRequires:  openssl-devel >= 1.1.0
BuildRequires:  pkgconfig
BuildRequires:  python3-Cython >= 3.0.10
BuildRequires:  python3-base >= 3.9
BuildRequires:  python3-devel
BuildRequires:  python3-packaging
BuildRequires:  python3-setuptools
BuildRequires:  python3-setuptools_scm
BuildRequires:  zsh
BuildRequires:  pkgconfig(libxxhash)
%if 0%{?suse_version} == 1320 || 0%{?sle_version} == 120200
BuildRequires:  bash-completion
%endif
%if %{with borg_sysblake2}
BuildRequires:  libb2-devel
%endif
%if %{with borg_newcompr}
BuildRequires:  liblz4-devel >= 1.7.0
BuildRequires:  libzstd-devel >= 1.3.0
%endif
# /SECTION
# SECTION runtime and extra requrements
# msgpack is not included with borg version >= 1.2.0 anymore
# The metadata is very specific about the version, the command will fail if msgpack is out of range -- boo#1198267
# See https://github.com/borgbackup/borg/blob/1.2.1/setup.py#L68 and update this for every version bump!
BuildRequires:  (python3-msgpack >= 1.0.3 with python3-msgpack <= 1.1.0)
Requires:       python3-packaging
Requires:       (python3-msgpack >= 1.0.3 with python3-msgpack <= 1.1.0)
%if 0%{?suse_version} > 1500
# upstream recommends a "Requires" if pyfuse3 is available
Requires:       python3-pyfuse3 >= 3.1.1
%else
Recommends:     python3-llfuse >= 1.3.8
%endif
# /SECTION
# SECTION docs requirements
BuildRequires:  python3-Sphinx
BuildRequires:  python3-sphinx_rtd_theme
%if %{with borg_guzzle}
BuildRequires:  python3-guzzle_sphinx_theme
%endif
# /SECTION
# SECTION testing requirements
%if %{with borg_test}
BuildRequires:  python3-dateutil
BuildRequires:  python3-pytest
BuildRequires:  python3-pytest-benchmark
BuildRequires:  python3-pytest-cov
BuildRequires:  python3-pytest-xdist
%endif
# /SECTION

%description
BorgBackup is a deduplicating backup program which stores deltas. It
supports compression and authenticated encryption as well,
facilitating frequent backups and storing to not fully trusted
targets.

%package doc
Summary:        Documentation files for borgbackup
Group:          Documentation/HTML
BuildArch:      noarch

%description doc
BorgBackup is a deduplicating backup program which stores deltas. It
supports compression and authenticated encryption as well,
facilitating frequent backups and storing to not fully trusted
targets.

Run borg for a commands overview and check out the docs at
%{_docdir}/%{name}/html/index.html.

%package bash-completion
Summary:        Bash Completion for %{name}
Group:          Productivity/Archiving/Backup
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (borgbackup and bash)
BuildArch:      noarch

%description bash-completion
BorgBackup is a deduplicating backup program which stores deltas. It
supports compression and authenticated encryption as well,
facilitating frequent backups and storing to not fully trusted
targets.

This package contains the bash completion script for borgbackup.

%package zsh-completion
Summary:        Zsh Completion for %{name}
Group:          Productivity/Archiving/Backup
Requires:       %{name} = %{version}
Requires:       zsh
Supplements:    (borgbackup and zsh)
BuildArch:      noarch

%description zsh-completion
BorgBackup is a deduplicating backup program which stores deltas. It
supports compression and authenticated encryption as well,
facilitating frequent backups and storing to not fully trusted
targets.

This package contains the zsh completion script for borgbackup.

%package fish-completion
Summary:        Fish Completion for %{name}
Group:          Productivity/Archiving/Backup
Requires:       %{name} = %{version}
Requires:       fish
Supplements:    (borgbackup and fish)
BuildArch:      noarch

%description fish-completion
BorgBackup is a deduplicating backup program which stores deltas. It
supports compression and authenticated encryption as well,
facilitating frequent backups and storing to not fully trusted
targets.

This package contains the fish completion script for borgbackup.

%prep
%setup -q
%if ! %{with borg_guzzle}
%patch -P 0 -p1
%endif

%ifnarch %ix86 %arm
  # https://github.com/borgbackup/borg/issues/6996
  sed -i 's/SUPPORT_32BIT_PLATFORMS = True/SUPPORT_32BIT_PLATFORMS = False/' src/borg/helpers/time.py
%endif
# remove bundled libraries, that we don't want to be included
rm -rf src/borg/algorithms/{lz4,zstd}
# remove bundled blake2 library, if appropriate
%if %{with borg_sysblake2}
rm -rf src/borg/algorithms/blake2
%endif
# remove precompiled Cython code
find src/ -name '*.pyx' | sed -e 's/.pyx/.c/g' | xargs rm -f
# better name for msgpack license
cp -a %{_datadir}/licenses/%{python_flavor}-msgpack/COPYING LICENSE.msgpack

%build
%{borg_openssl_prefix} %{borg_libzstd_prefix} %{borg_liblz4_prefix} %{borg_libxxhash_prefix} %{borg_libacl_prefix} CFLAGS="%{optflags}" CXXFLAGS="%{optflags}" python3 setup.py build
export PYTHONPATH=$(pwd)/build/lib.linux-$(uname -m)-%{py3_ver}
%make_build -C docs html man && rm docs/_build/html/.buildinfo

%install
%{borg_libacl_prefix} %{borg_libxxhash_prefix} %{borg_openssl_prefix} %{borg_liblz4_prefix} %{borg_libzstd_prefix} python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
# install all man pages
mkdir -p %{buildroot}%{_mandir}/man1
install -m 0644 docs/man/borg*.1 %{buildroot}%{_mandir}/man1
# install shell completions
install -D -m 0644 scripts/shell_completions/bash/borg %{buildroot}/%{_datadir}/bash-completion/completions/borg
install -D -m 0644 scripts/shell_completions/zsh/_borg %{buildroot}/%{_datadir}/zsh/site-functions/_borg
install -D -m 0644 scripts/shell_completions/fish/borg.fish %{buildroot}/%{_datadir}/fish/vendor_completions.d/borg.fish
# link duplicate files
%fdupes %{buildroot}/%{python3_sitearch}/borgbackup-%{version}-py%{py3_ver}.egg-info/
# fix wrong-file-end-of-line-encoding
sed -i 's/\r$//' docs/_build/html/_static/fonts/open-sans/stylesheet.css
sed -i 's/\r$//' docs/_build/html/_static/fonts/source-serif-pro/LICENSE.txt

%if %{with borg_test}
%check
# tests need to run in the build env for some reason
export py3_ver_nodot=$(echo %{py3_ver} | tr -d '.')
export PYTHONPATH=$(pwd)/build/lib.linux-$(uname -m)-cpython-$py3_ver_nodot
TEST_SELECTOR="not benchmark"
LANG=en_US.UTF-8 py.test -x -vk "$TEST_SELECTOR" $PYTHONPATH/borg/testsuite/*.py
%endif

%files
%doc CHANGES.rst README.rst
%license LICENSE LICENSE.msgpack
%{python3_sitearch}/borg/
%{python3_sitearch}/borgbackup-%{version}-py%{py3_ver}.egg-info
%{_bindir}/borg
%{_bindir}/borgfs
%{_mandir}/man1/borg*.1%{?ext_man}

%files doc
%doc docs/_build/html

%files bash-completion
%{_datadir}/bash-completion/completions/borg

%files zsh-completion
%{_datadir}/zsh/site-functions/_borg

%files fish-completion
%{_datadir}/fish/vendor_completions.d/borg.fish

%changelog
* Fri Jul 12 2024 Andreas Prittwitz <m4ng4n@gmx.de>
- update to version 1.4.0
- adjust copyright header
- add two new variable definitions needed by borgbackup >= 1.4.0:
  "BORG_LIBXXHASH_PREFIX=" and "BORG_LIBACL_PREFIX="
- change requirements for
  libacl-devel to >= 2.2.47
  python3-Cython to >=3.0.10
  python3-base to >= 3.9
  python3-msgpack to >= 1.0.3 and <= 1.1.0
  python3-llfuse to >= 1.3.8
- remove obsolete conflict for python3-msgpack = 1.0.1
- add %%{borg_libacl_prefix} and %%{borg_libxxhash_prefix} to the
  %%build and the %%install section
- Upgrade Notes borg 1.2.x to 1.4.x:
  * If you currently use borg 1.2.5+: no upgrade steps needed (if
    you already did them when upgrading to that version,
    otherwise see below).
  * If you currently use borg 1.2.0 .. 1.2.4, read and follow
    “Pre-1.2.5 archives spoofing vulnerability (CVE-2023-36811)”
    section in the changelog, see link below.
- Compatibility notes:
  * By default, borg 1.4 will behave quite similar to borg 1.2
    (it was forked off from 1.2-maint branch at 1.2.7).
  * the slashdot hack: be careful not to accidentally give paths
    containing /./ to “borg create” if you do not want to trigger
    this feature (which strips the left part of the path from
    archived items).
  * BORG_EXIT_CODES=modern is a feature that borg script, wrapper
    and GUI authors may want to use to get more specific error
    and warning return codes from borg. In that case, of course
    they will need to make sure to correctly deal with these new
    codes, see the internals/frontends docs.
- Update to version 1.4:
  * BORG_EXIT_CODES=modern: optional more specific return codes
    (for errors and warnings)
  * borg create: add the "slashdot hack" to strip recursion root
    prefixes
  * borg version REPO: show version of borg client and server
- Other bigger changes:
  * ACL code: refactor, improve acl_get / acl_set error handling
  * removed bundled 3rd party code (lz4/zstd/xxhash)
  * modernised python packaging (use pyproject.toml, use less
    setup.py)
  * use pyinstaller 6.7.0 and python 3.11 for the binary builds
  * new naming convention for fat binaries (include glibc version
    for linux)
  Full changelog:
  https://borgbackup.readthedocs.io/en/1.4-maint/changes.html
* Sun Jun 30 2024 Andreas Prittwitz <m4ng4n@gmx.de>
- Update to version 1.2.8
  + Fixes:
  * check: fix return code and log level for index entry value
    discrepancies
  * with-lock: catch FileNotFoundError exception, print error
    msg, #8022
  * benchmark: inherit options --rsh --remote-path, #8099
  * fix Ctrl-C / SIGINT behaviour for pyinstaller-made binaries,
    [#8155]
  + New features:
  * upgrade --check-tam: check manifest TAM auth, exit with rc=1
    if there are issues.
  * upgrade --check-archives-tam: check archives TAM auth, exit
    with rc=1 if there are issues.
  + Other changes:
  * allow msgpack 1.0.8 (this might fix memory leaks with Python
    3.12), #8133
  * use the latest Cython 0.29.x
  * vagrant:
  * use / build binaries with python 3.9.19
  * use generic/openbsd7 box
  * docs:
  * simplify TAM-related upgrade docs using the new commands
  * improve docs for borg with-lock, #8022
  * add more infos borg check --repair recreating the shadow
    index to change log, see #6687
  Full Changelog:
  https://github.com/borgbackup/borg/blob/1.2.8/docs/changes.rst#version-128-2024-03-29
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Sat Jan 13 2024 Andreas Prittwitz <m4ng4n@gmx.de>
- Update to version 1.2.7
- Update Requires/BuildRequires to
  (python3-msgpack >= 0.5.6 with python3-msgpack <= 1.0.7)
  + Fixes:
  - docs: CVE-2023-36811 upgrade steps: consider checkpoint
    archives, #7802
  - check/compact: fix spurious reappearance of orphan chunks
    since borg 1.2, #6687 - this consists of 2 fixes:
  - for existing chunks: check --repair: recreate shadow index,
    [#6687]
  - for newly created chunks: update shadow index when doing a
    double-put, #5661
  - LockRoster.modify: no KeyError if element was already gone,
    [#7937]
  - create --X-from-command: run subcommands with a clean
    environment, #7916
  - list --sort-by: support "archive" as alias of "name", #7873
  - fix rc and msg if arg parsing throws an exception, #7885
  + Other changes:
  - support and test on Python 3.12
  - include unistd.h in _chunker.c (fix for Python 3.13)
  - allow msgpack 1.0.6 and 1.0.7
  - TAM issues: show tracebacks, improve borg check logging,
    [#7797]
  - replace "datetime.utcfromtimestamp" with custom helper to
    avoid deprecation warnings when using Python 3.12
  + vagrant:
  - use generic/debian9 box, fixes #7579
  - add VM with debian bookworm / test on OpenSSL 3.0.x.
  + docs:
  - not only attack/unsafe, can also be a fs issue, #7853
  - point to CVE-2023-36811 upgrade steps from borg 1.1 to 1.2
    upgrade steps, #7899
  - upgrade steps needed for all kinds of repos (including
    "none" encryption mode), #7813
  - upgrade steps: talk about consequences of borg check, #7816
  - upgrade steps: remove period that could be interpreted as
    part of the command
  - automated-local.rst: use GPT UUID for consistent udev rule
  - create disk/partition sector backup by disk serial number,
    [#7934]
  - update macOS hint about full disk access
  - clarify borg prune -a option description, #7871
  - readthedocs: also build offline docs (HTMLzip), #7835
  - frontends: add "check.rebuild_refcounts" message
  Full Changelog:
  https://github.com/borgbackup/borg/blob/1.2.7/docs/changes.rst#version-127-2023-12-02
* Wed Oct 11 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.2.6:
  + The upgrade procedure docs as published with borg 1.2.5 did not
    work, if the repository had archives resulting from a borg
    rename or borg recreate operation.
  + The updated docs now use
    BORG_WORKAROUNDS=ignore_invalid_archive_tam at some places to
    avoid that issue.
- Changes from version 1.2.5:
  + Fixes:
  - Security: fix pre-1.2.5 archives spoofing vulnerability
    (CVE-2023-36811, boo#1214809).
  - rename/recreate: correctly update resulting archive’s TAM.
  - create: do not try to read parent dir of recursion root.
  - extract: fix false warning about pattern never matching.
  - diff: remove surrogates before output,
  - compact: clear empty directories at end of compact process.
  - create --files-cache=size: fix crash,
  - keyfiles: improve key sanity check.
  - only warn about “invalid” chunker params.
  - ProgressIndicatorPercent: fix space computation for wide
    chars.
  - improve argparse validator error messages.
  + New features:
  - mount: make up volname if not given (macOS), #7690. macFUSE
    supports a volname mount option to give what finder displays
    on the desktop / in the directory view. if the user did not
    specify it, we make something up, because otherwise it would
    be “macFUSE Volume 0 (Python)” and hide the mountpoint
    directory name.
  - BORG_WORKAROUNDS=authenticated_no_key to extract from
    authenticated repos without key.
* Sat Mar 25 2023 Andreas Prittwitz <m4ng4n@gmx.de>
- change requirement: python3-Cython >= 0.29.33
* Fri Mar 24 2023 Andreas Prittwitz <m4ng4n@gmx.de>
- update to 1.2.4
  New features:
  * import-tar: add --ignore-zeros to process concatenated tars,
    [#7432].
  * debug id-hash: computes file/chunk content id-hash, #7406
  * diff: --content-only does not show mode/ctime/mtime changes,
    [#7248]
  * diff: JSON strings in diff output are now sorted
    alphabetically
  Bug fixes:
  * xattrs: fix namespace processing on FreeBSD, #6997
  * diff: fix path related bug seen when addressing deferred
    items.
  * debug get-obj/put-obj: always give chunkid as cli param, see
    [#7290] (this is an incompatible change, see also borg debug
    id-hash)
  * extract: fix mtime when ResourceFork xattr is set (macOS
    specific), #7234
  * recreate: without --chunker-params, do not re-chunk, #7337
  * recreate: when --target is given, do not detect "nothing to
    do". use case: borg recreate -a src --target dst can be used
    to make a copy of an archive inside the same repository,
    [#7254].
  * set .hardlink_master for ALL hardlinkable items, #7175
  * locking: fix host, pid, tid order. tid (thread id) must be
    parsed as hex from lock file name.
  * update development.lock.txt, including a setuptools security
    fix, #7227
  Other changes:
  * requirements: allow msgpack 1.0.5 also
  * upgrade Cython to 0.29.33
  * hashindex minor fixes, refactor, tweaks, tests
  * use os.replace not os.rename
  * remove BORG_LIBB2_PREFIX (not used any more)
  * docs:
  * BORG_KEY_FILE: clarify docs, #7444
  * update FAQ about locale/unicode issues, #6999
  * improve mount options rendering, #7359
  * make timestamps in manual pages reproducible
  * installation: update Fedora in distribution list, #7357
  * tests:
  * fix test_size_on_disk_accurate for large st_blksize, #7250
  * add same_ts_ns function and use it for relaxed timestamp
    comparisons
  * "auto" compressor tests: don't assume a specific size, do not
    assume zlib is better than lz4, #7363
  * add test for extracted directory mtime
  * vagrant:
  * upgrade local freebsd 12.1 box -> generic/freebsd13 box
    (13.1)
  * use pythons > 3.8 which work on freebsd 13.1
  * pyenv: also install python 3.11.1 for testing
  * pyenv: use python 3.10.1, 3.10.0 build is broken on freebsd
  Full changelog:
  https://github.com/borgbackup/borg/blob/1.2.4/docs/changes.rst#version-124-2023-03-23
* Mon Dec 26 2022 Hans-Peter Jansen <hpj@urpla.net>
- Update to 1.2.3
  Fixes:
  * create: fix --list --dry-run output for directories, #7209
  * diff/recreate: normalize chunker params before comparing them,
    [#7079]
  * check: fix uninitialised variable if repo is completely empty,
    [#7034]
  * xattrs: improve error handling, #6988
  * fix args.paths related argparsing, #6994
  * archive.save(): always use metadata from stats (e.g. nfiles,
    size, ...), #7072
  * tar_filter: recognize .tar.zst as zstd, #7093
  * get_chunker: fix missing sparse=False argument, #7056
  * file_integrity.py: make sure file_fd is always closed on exit
  * repository: cleanup(): close segment before unlinking
  * repository: use os.replace instead of os.rename
  Other changes:
  * remove python < 3.7 compatibility code
  * do not use version_tuple placeholder in setuptools_scm
    template
  * CI: fix tox4 passenv issue, #7199
  * vagrant: update to python 3.9.16, use the openbsd 7.1 box
  * misc. test suite and docs fixes / improvements
  * remove deprecated --prefix from docs, #7109
  * Windows: use MSYS2 for Github CI, remove Appveyor CI
  More info:
  * https://github.com/borgbackup/borg/blob/1.2.3/docs/changes.rst#version-123-2022-12-24
* Sat Sep 17 2022 Andreas Prittwitz <m4ng4n@gmx.de>
- Update to 1.2.2
- Update requirements: openssl-devel >= 1.1.0
  New features:
  * prune/delete --checkpoint-interval=1800 and ctrl-c/SIGINT
    support, #6284
  Fixes:
  * SaveFile: use a custom mkstemp with mode support, #6933,
    [#6400], #6786. This fixes umask/mode/ACL issues (and also
    "chmod not supported" exceptions seen in 1.2.1) of files
  * updated using SaveFile, e.g. the repo config.
  * hashindex_compact: fix eval order (check idx before use),
    [#5899]
  * create --paths-from-(stdin|command): normalize paths, #6778
  * secure_erase: avoid collateral damage, #6768. If a hardlink
    copy of a repo was made and a new repo config shall be
    saved, do NOT fill in random garbage before deleting the
    previous repo config, because that would damage the hardlink
    copy.
  * list: fix {flags:<WIDTH>} formatting, #6081
  * check: try harder to create the key, #5719
  * misc commands: ctrl-c must not kill other subprocesses, #6912
    borg create with a remote repo via ssh
    borg create --content-from-command
    borg create --paths-from-command
  * (de)compression filter process of import-tar / export-tar
  Other changes:
  * deprecate --prefix, use -a / --glob-archives, see #6806
  * make setuptools happy ("package would be ignored"), #6874
  * fix pyproject.toml to create a fixed _version.py file,
    compatible with both old and new setuptools_scm version,
    [#6875]
  * automate asciinema screencasts
  * CI: test on macOS 12 without fuse / fuse tests (too
    troublesome on github CI due to kernel extensions needed by
    macFUSE)
  * tests: fix test_obfuscate byte accounting
  * repository: add debug logging for issue #6687
  * _chunker.c: fix warnings on macOS
  * requirements.lock.txt: use the latest cython 0.29.32
  docs:
  * add info on man page installation, #6894
  * update archive_progress json description about
    "finished", #6570
  * json progress_percent: some values are optional, #4074
  * FAQ: full quota / full disk, #5960
  * correct shell syntax for installation using git
- Full Changelog: /usr/share/doc/packages/borgbackup/CHANGES.rst
* Mon Aug 29 2022 Bernhard Wiedemann <bwiedemann@suse.com>
- Support dates beyond 2038 on 64-bit platforms
* Fri Aug 12 2022 Hans-Peter Jansen <hpj@urpla.net>
- Fix package %%checks
- the tests
  test_progress_percentage_sameline and test_progress_percentage_step
  seem to do work again
* Sat Jun 25 2022 Ben Greiner <code@bnavigator.de>
- Update requirements
  * Be very specific with python3-msgpack: This prevents users to
    upgrade their Tumbleweed system with an incompatible version
  * Clean up
* Fri Jun 24 2022 Andreas Prittwitz <m4ng4n@gmx.de>
- Update to 1.2.1
  Compatibility notes:
  * matching of path patterns has been aligned with borg storing
    relative paths. Borg archives file paths without leading
    slashes. Previously, include/exclude patterns could contain
    leading slashes. You should check your patterns and remove
    leading slashes.
  Fixes:
  * create: skip with warning if opening the parent dir of
    recursion root fails, #6374
  * create: fix crash. metadata stream can produce all-zero
    chunks, #6587
  * fix crash when computing stats, escape %% chars in archive
    name, #6500
  * fix transaction rollback: use files cache filename as found
    in txn.active/, #6353
  * import-tar: kill filter process in case of borg exceptions,
    [#6401] #6681
  * import-tar: fix mtime type bug
  * ensure_dir: respect umask for created directory modes, #6400
  * SaveFile: respect umask for final file mode, #6400
  * check archive: improve error handling for corrupt archive
    metadata block, make robust_iterator more robust, #4777
  * pre12-meta cache: do not use the cache if want_unique is
    True, #6612
  * fix scp-style repo url parsing for ip v6 address, #6526
  * mount -o versions: give clear error msg instead of crashing.
    it does not make sense to request versions view if you only
    look at 1 archive, but the code shall not crash in that case
    as it did, but give a clear error msg.
  * show_progress: add finished=true/false to archive_progress
    json, #6570
  * delete/prune: fix --iec mode output (decimal vs.
    binary units), #6606
  * info: fix authenticated mode repo to show
    "Encrypted: No", #6462
  * diff: support presence change for blkdev, chrdev and fifo
    items, #6615
  New features:
  * delete: add repository id and location to prompt, #6453
  * borg debug dump-repo-objs --ghost: new --segment=S
  - -offset=O options
  Other changes:
  * support python 3.11
  * allow msgpack 1.0.4, #6716
  * load_key: no key is same as empty key, #6441
  * give a more helpful error msg for unsupported key formats,
    [#6561]
  * better error msg for defect or unsupported repo configs, #6566
  * docs:
  * document borg 1.2 pattern matching behavior change, #6407
  * Make clear that absolute paths always go into the matcher as
    if they are relative (without leading slash). Adapt all
    examples accordingly.
  * authentication primitives: improved security and performance
    infos
  * mention BORG_FILES_CACHE_SUFFIX as alternative to
    BORG_FILES_CACHE_TTL, #5602
  * FAQ: add a hint about --debug-topic=files_cache
  * improve borg check --max-duration description
  * fix values of TAG bytes, #6515
  * borg compact --cleanup-commits also runs a normal compaction,
    [#6324]
  * virtualization speed tips
  * recommend umask for passphrase file perms
  * borg 1.2 is security supported
  * update link to ubuntu packages, #6485
  * use --numeric-ids in pull mode docs
  * remove blake2 docs, blake2 code not bundled any more, #6371
  * clarify on-disk order and size of segment file log
    entry fields, #6357
  * docs building: do not transform --/--- to unicode dashes
  * tests:
  * check that borg does not require pytest for normal usage,
    fixes #6563
  * fix OpenBSD symlink mode test failure, #2055
  * vagrant:
  * darwin64: remove fakeroot, #6314
  * update development.lock.txt
  * use pyinstaller 4.10 and python 3.9.13 for binary build
  * upgrade VMCPUS and xdistn from 4 to 16, maybe this speeds
    up the tests
  * crypto:
  * use hmac.compare_digest instead of ==, #6470
  * hmac_sha256: replace own cython wrapper code by hmac.digest
    python stdlib (since py38)
  * hmac and blake2b minor optimizations and cleanups
  * removed some unused crypto related code, #6472
  * avoid losing the key (potential use-after-free). this never
    could happen in 1.2 due to the way we use the code. The issue
    was discovered in master after other changes, so we also
    "fixed" it here before it bites us.
  * setup / build:
  * add pyproject.toml, fix sys.path, #6466
  * setuptools_scm: also require it via pyproject.toml
  * allow extra compiler flags for every extension build
  * fix misc. C / Cython compiler warnings, deprecation warnings
  * fix zstd.h include for bundled zstd, #6369
  * source using python 3.8 features:
    pyupgrade --py38-plus ./**/*.py
- Full changelog at /usr/share/doc/packages/borgbackup/CHANGES.rst
* Fri Jun 17 2022 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Don't hardcode the python version
* Mon Apr 11 2022 Scott Bradnick <scott.bradnick@suse.com>
- Adding 'Requires: python3-msgpack' per boo#1198267.
* Sun Apr  3 2022 Hans-Peter Jansen <hpj@urpla.net>
- Note removal of borgbackup-1.1.17-old-sphinx-api.patch
- Adjust copyright years
* Sat Apr  2 2022 Andreas Prittwitz <m4ng4n@gmx.de>
- revert changes to copyright header
* Wed Mar 30 2022 Andreas Prittwitz <m4ng4n@gmx.de>
- Update to 1.2.0
  Compatibility notes:
  * dropped support / testing for older Pythons, minimum
    requirement is 3.8. In case your OS does not provide Python >=
    3.8, consider using our binary, which does not need an
    external Python interpreter. Or continue using borg 1.1.x,
    which is still supported.
  * freeing repository space only happens when "borg compact" is
    invoked.
  * mount: the default for --numeric-ids is False now (same as
    borg extract)
  * borg create --noatime is deprecated. Not storing atime is the
    default behaviour now (use --atime if you want to store the
    atime).
  * list: corrected mix-up of "isomtime" and "mtime" formats.
    Previously, "isomtime" was the default but produced a verbose
    human format, while "mtime" produced a ISO-8601-like format.
    The behaviours have been swapped (so "mtime" is human,
    "isomtime" is ISO-like), and the default is now "mtime".
    "isomtime" is now a real ISO-8601 format ("T" between date and
    time, not a space).
  * create/recreate --list: file status for all files used to get
    announced AFTER the file (with borg < 1.2). Now, file status
    is announced BEFORE the file contents are processed. If the
    file status changes later (e.g. due to an error or a content
    change), the updated/final file status will be printed again.
  * removed deprecated-since-long stuff (deprecated since):
    command "borg change-passphrase" (2017-02), use "borg key ..."
    option "--keep-tag-files" (2017-01), use "--keep-exclude-tags"
    option "--list-format" (2017-10), use "--format"
    option "--ignore-inode" (2017-09), use "--files-cache" w/o "inode"
    option "--no-files-cache" (2017-09), use "--files-cache=disabled"
  * removed BORG_HOSTNAME_IS_UNIQUE env var. to use borg you must
    implement one of these 2 scenarios:
    the combination of FQDN and result of uuid.getnode() must be
    unique and stable (this should be the case for almost
    everybody, except when having duplicate FQDN and MAC address
    or all-zero MAC address) if you are aware that 1) is not the
    case for you, you must set BORG_HOST_ID env var to something
    unique.
  * exit with 128 + signal number, #5161. if you have scripts
    expecting rc == 2 for a signal exit, you need to update them
    to check for >= 128.
  Fixes:
  * diff: reduce memory consumption, fix is_hardlink_master, #6295
  * compact: fix / improve freeable / freed space log output
  * derive really freed space from quota use before/after, #5679
    do not say "freeable", but "maybe freeable" (based on hint,
    unsure)
  * fix race conditions in internal SaveFile function, #6306 #6028
  * implement internal safe_unlink (was: truncate_and_unlink)
    function more safely: usually it does not truncate any more,
    only under "disk full" circumstances and only if there is only
    one hardlink.
    see: https://github.com/borgbackup/borg/discussions/6286
  Other changes:
  * info: use a pre12-meta cache to accelerate stats for borg
    < 1.2 archives. the first time borg info is invoked on a
    borg 1.1 repo, it can take a rather long time computing and
    caching some stats values for 1.1 archives, which borg 1.2
    archives have in their archive metadata structure. be patient,
    esp. if you have lots of old archives. following invocations
    are much faster due to the cache. related change: add archive
    name to calc_stats progress display.
  * docs:
  * add borg 1.2 upgrade notes, #6217
  * link to borg placeholders and borg patterns help
  * init: explain the encryption modes better
  * clarify usage of patternfile roots
  * put import-tar docs into same file as export-tar docs
  * explain the difference between a path that ends with or
    without a slash, #6297
- Full changelog at
  https://github.com/borgbackup/borg/blob/1.2.0/docs/changes.rst#version-120-2022-02-22-220222--
- change BuildRequires to python >= 3.8
- supports msgpack up to 1.0.3
- add %%define for required borgbackup prefixes
- Add BuildRequires: python3-msgpack, it ist not included with
  borgbackup v 1.2.0 anymore
- Add BuildRequires: python3-dateutil, otherwise borgbackup will
  not build.
- Add python3-pyfuse3 as a Requirement because upstream recommends
  this if pyfuse3 is available on the system. Otherwise we are not
  able to mount archives with borgbackup
- change path for msgpack license copy.
* Tue Jul 13 2021 Hans-Peter Jansen <hpj@urpla.net>
- Update to 1.1.17 (2021-07-12):
  Compatibility notes:
  * When upgrading from borg 1.0.x to 1.1.x, please note:
  * read all the compatibility notes for 1.1.0*, starting from
    1.1.0b1.
  * borg upgrade: you do not need to and you also should not run
    it.
  * borg might ask some security-related questions once after
    upgrading. You can answer them either manually or via
    environment variable. One known case is if you use unencrypted
    repositories, then it will ask about a unknown unencrypted
    repository one time.
  * your first backup with 1.1.x might be significantly slower (it
    might completely read, chunk, hash a lot files) - this is due
    to the –files-cache mode change (and happens every time you
    change mode). You can avoid the one-time slowdown by using the
    pre-1.1.0rc4-compatible mode (but that is less safe for
    detecting changed files than the default). See the –files-
    cache docs for details.
  * 1.1.11 removes WSL autodetection (Windows 10 Subsystem for
    Linux). If WSL still has a problem with sync_file_range, you
    need to set BORG_WORKAROUNDS=basesyncfile in the borg process
    environment to work around the WSL issue.
  * 1.1.14 changes return codes due to a bug fix: In case you have
    scripts expecting rc == 2 for a signal exit, you need to
    update them to check for >= 128 (as documented since long).
  * 1.1.15 drops python 3.4 support, minimum requirement is 3.5
    now.
  * 1.1.17 install_requires the “packaging” pypi package now.
  Fixes:
  * pyinstaller dir-mode: fix pyi detection / LIBPATH treatment,
    [#5897]
  * handle crash due to kill stale lock race, #5828
  * fix BORG_CACHE_DIR crashing borg if empty, #5216
  * create –dry-run: fix display of kept tagfile, #5834
  * fix missing parameter in “did not consistently fail” msg,
    [#5822]
  * missing / healed chunks: always tell chunk ID, #5704
  * benchmark: make sure cleanup happens even on exceptions, #5630
  New features:
  * implement BORG_SELFTEST env variable, #5871. this can be used
    to accelerate borg startup a bit. not recommended for normal
    usage, but borg mass hosters with a lot of borg invocations
    can save some resources with this. on my laptop, this saved
    ~100ms cpu time (sys+user) per borg command invocation.
  * implement BORG_LIBC env variable to give the libc filename,
    [#5870]. you can use this if a borg does not find your libc.
  * check: add progress indicator for archive check.
  * allow –files-cache=size (not recommended, make sure you know
    what you do)
  Other changes:
  * Python 3.10 now officially supported! we test on py310-dev on
    github CI since a while and now also on the vagrant machines,
    so it should work ok.
  * github CI: test on py310 (again)
  * get rid of distutils, use packaging and setuptools. distutils
    is deprecated and gives warnings on py 3.10.
  * setup.py: rename “clean” to “clean2” to avoid shadowing the
    “clean” command.
  * remove libc filename fallback for the BSDs (there is no
    “usual” name)
  * cleanup flake8 checks, fix some pep8 violations.
  * docs building: replace deprecated function “.add_stylesheet()”
    for Sphinx 4 compatibility
  * docs:
  * add a hint on sleeping computer and ssh connections, #5301
  * update the documentation on hacked backup client, #5480
  * improve docs/FAQ about append-only remote repos, #5497
  * complement the documentation for pattern files and exclude
    files, #5520
  * “filename with spaces” example added to exclude file, #5236
    note: no whitespace escaping needed, processed by borg.
  * add info on renaming repositories, #5240
  * clarify borg check –verify-data, #5808
  * add notice about defective hardware to check documentation,
    [#5753]
  * add paragraph added in #5855 to utility documentation source
  * add missing leading slashes in help patterns, #5857
  * clarify “you will need key and passphrase” borg init warning,
    [#4622]
  * pull mode: add some warnings, #5827
  * mention tar –compare (compare archive to fs files), #5880
  * fix typos, backport of #5597
  * vagrant:
  * add py3.7.11 for binary build, also add 3.10-dev.
  * use latest Cython 0.29.23 for py310 compat fixes.
  * more RAM for openindiana upgrade plan resolver, it just hangs
    (swaps?) if there is too little RAM.
  * fix install_pyenv to adapt to recent changes in pyenv (same as
    in master now).
  * use generic/netbsd9 box, copied from master branch.
- Reformatted Paolos last changelog
- Revert logic of borgbackup-1.1.16-fix-sphinx-api.patch:
  borgbackup-1.1.17-old-sphinx-api.patch
- Allow to use old version of xxhash library (might crash on ARM),
  but an update is in enqueued
* Fri Jul  2 2021 Hans-Peter Jansen <hpj@urpla.net>
- Fix documentation generation with
  borgbackup-1.1.16-fix-sphinx-api.patch for Leap >= 15.3
* Sun May 16 2021 ecsos <ecsos@opensuse.org>
- Remove the version from recommends pyfuse3,
  because it doesn't work in suse.
* Sun May 16 2021 ecsos <ecsos@opensuse.org>
- Use recommends pyfuse3 instead of llfuse for Tumbleweed.
  Upstream says use primary pyfuse3 and secondary llfuse.
* Sun Mar 28 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.1.16:
  Fixes:
  * setup.py: add special openssl prefix for Apple M1
    compatibility
  * do not recurse into duplicate roots, #5603
  * remove empty shadowed_segments lists, #5275, #5614
  * fix libpython load error when borg fat binary / dir-based
    binary is invoked via a symlink by upgrading pyinstaller to
    v4.2, #5688
  * config: accept non-int value (like 500M or 100G) for
    max_segment_size or storage_quota, #5639. please note: when
    setting a non-int value for this in a repo config, using the
    repo will require borg >= 1.1.16.
  New features:
  * bundled msgpack: drop support for old buffer protocol to
    support Python 3.10
  * verbose files cache logging via --debug-topic=files_cache,
    [#5659]. Use this if you suspect that borg does not detect
    unmodified files as expected.
  * create/extract: add --noxattrs and --noacls option, #3955.
    when given with borg create, borg will not get xattrs / ACLs
    from input files (and thus, it will not archive xattrs / ACLs).
    when given with borg extract, borg will not read xattrs / ACLs
    from archive and will not set xattrs / ACLs on extracted files.
  * diff: add --json-lines option, #3765
  Other changes:
  * Tab completion support for additional archives for 'borg
    delete'
  * repository: deduplicate code of put and delete, no functional
    change
  Docs updates
* Tue Feb  9 2021 Antonio Larrosa <alarrosa@suse.com>
- Update to 1.1.15:
  * drops python 3.4 support, minimum requirement is 3.5 now.
  Fixes:
  * extract:
    + improve exception handling when setting xattrs, #5092.
    + emit a warning message giving the path, xattr key and error
    message.
    + continue trying to restore other xattrs and bsdflags of the
    same file after an exception with xattr-setting happened.
  * export-tar:
    + set tar format to GNU_FORMAT explicitly, #5274
    + fix memory leak with ssh: remote repository, #5568
    + fix potential memory leak with ssh: remote repository with
    partial extraction
  * create: fix --dry-run and --stats coexistence, #5415
  * use --timestamp for {utcnow} and {now} if given, #5189
  New features:
  * create: implement --stdin-mode, --stdin-user and --stdin-group,
    [#5333]
  * allow appending the files cache filename with
    BORG_FILES_CACHE_SUFFIX env var
  Other changes:
  * drop python 3.4 support, minimum requirement is 3.5 now.
  * enable using libxxhash instead of bundled xxh64 code
  * update llfuse requirements (1.3.8)
  * set cython language_level in some files to fix warnings
  * allow EIO with warning when trying to hardlink
  * PropDict: fail early if internal_dict is not a dict
  * update shell completions
  * tests / CI
    + add a test for the hashindex corruption bug, #5531 #4829
    + fix spurious failure in test_cache_files, #5438
    + added a github ci workflow
    + reduce testing on travis, no macOS, no py3x-dev, #5467
    + travis: use newer dists, native py on dist
  * vagrant:
    + remove jessie and trusty boxes, #5348 #5383
    + pyinstaller 4.0, build on py379
    + binary build on stretch64, #5348
    + remove easy_install based pip installation
  * docs:
    + clarify '--one-file-system' for btrfs, #5391
    + add example for excluding content using the --pattern cmd
    line arg
    + complement the documentation for pattern files and exclude
    files, #5524
    + made ansible playbook more generic, use package instead of
    pacman. also change state from "latest" to "present".
    + complete documentation on append-only remote repos, #5497
    + internals: rather talk about target size than statistics,
    [#5336]
    + new compression algorithm policy, #1633 #5505
    + faq: add a hint on sleeping computer, #5301
    + note requirements for full disk access on macOS Catalina,
    [#5303]
    + fix/improve description of borg upgrade hardlink usage,
    [#5518]
  * modernize 1.1 code:
    + drop code/workarounds only needed to support Python 3.4
    + remove workaround for pre-release py37 argparse bug
    + removed some outdated comments/docstrings
    + requirements: remove some restrictions, lock on current
    versions
* Wed Dec 16 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.1.14:
  Compatibility notes:
  * changes return codes due to a bug fix: In case you have scripts \
    expecting rc == 2 for a signal exit, you need to update them
    to check for >= 128 (as documented since long).
  Fixes:
  * check --repair: fix potential data loss when interrupting it, #5325
  * exit with 128 + signal number (as documented) when borg is killed by a signal, #5161
  * fix hardlinked CACHEDIR.TAG processing, #4911
  * create --read-special: .part files also should be regular files, #5217
  Other changes:
  * upgrade bundled xxhash to 0.7.4
  * prettier error message when archive gets too big
  * check/recreate are not "experimental" any more
    (but still potentially dangerous)
  * use "allow/deny list" instead of "white/black list" wording
  * update docs
* Mon Jun  8 2020 Antonio Larrosa <alarrosa@suse.com>
- Update to 1.1.13:
  * rebuilt using a current Cython version, compatible with
    python 3.8, #5214
- Update to 1.1.12:
  Fixes:
  * fix preload-related memory leak, #5202.
  * mount / borgfs (FUSE filesystem):
    + fix FUSE low linear read speed on large files, #5067
    + fix crash on old llfuse without birthtime attrs, #5064 -
    accidentally we required llfuse >= 1.3. Now also old llfuse works again.
    + set f_namemax in statfs result, #2684
  * update precedence of env vars to set config and cache paths, #4894
  * correctly calculate compression ratio, taking header size into
    account, too
  New features:
  * --bypass-lock option to bypass locking with read-only repositories
  Other changes:
  * upgrade bundled zstd to 1.4.5
  * travis: adding comments and explanations to Travis config/install
    script, improve macOS builds.
  * tests: test_delete_force: avoid sporadic test setup issues, #5196
  * misc. vagrant fixes
  * the binary for macOS is now built on macOS 10.12
  * the binaries for Linux are now built on Debian 8 "Jessie", #3761
  * docs:
    + PlaceholderError not printed as JSON, #4073
    + "How important is Borg config?", #4941
    + make Sphinx warnings break docs build, #4587
    + some markup / warning fixes
    + add "updating borgbackup.org/releases" to release checklist, #4999
    + add "rendering docs" to release checklist, #5000
    + clarify borg init's encryption modes
    + add note about patterns and stored paths, #4160
    + add upgrade of tools to pip installation how-to
    + document one cause of orphaned chunks in check command, #2295
    + linked recommended restrictions to ssh public keys on borg servers
    in faq, #4946
- Remove patch already included in 1.1.12:
  * 0001-rename-local-preload-function-to-not-overwrite-keyword-argument.patch
* Tue Jun  2 2020 Antonio Larrosa <alarrosa@suse.com>
- Add patch to fix a memory issue that in some cases might make
  borg use more than 32 GB of memory for an operation that shouldn't
  consume any memory at all, thus forcing the kernel to kill the process:
  * 0001-rename-local-preload-function-to-not-overwrite-keyword-argument.patch
* Thu May  7 2020 Hans-Peter Jansen <hpj@urpla.net>
- Add libb2 dependency, where appropriate (avoids bundling libb2)
- Remove outdated build fixes from spec
- Provide proper compile flags
- Install all available man files
- Disable 2 progress related tests, that fail for TW
* Sat Mar 14 2020 Hans-Peter Jansen <hpj@urpla.net>
- Add fdupes build dependency
- break overlong lines in changelog
* Thu Mar 12 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.1.11
  Fixes:
  * fixed potential index corruption / data loss issue due to bug in
    hashindex_set, #4829 Please read and follow the more detailled notes
    close to the top of this document.
  * upgrade bundled xxhash to 0.7.3, #4891 0.7.2 is the minimum requirement
    for correct operations on ARMv6 in non-fixup mode, where unaligned memory
    accesses cause bus errors. 0.7.3 adds some speedups and libxxhash 0.7.3
    even has a pkg-config file now.
  * upgrade bundled lz4 to 1.9.2
  * upgrade bundled zstd to 1.4.4
  * fix crash when upgrading erroneous hints file, #4922
  * extract:
  - fix KeyError for "partial" extraction, #4607
  - fix "partial" extract for hardlinked contentless file types, #4725
  - fix preloading for old (0.xx) remote servers, #4652
  - fix confusing output of borg extract --list --strip-components, #4934
  * delete: after double-force delete, warn about necessary repair, #4704
  * create: give invalid repo error msg if repo config not found, #4411
  * mount: fix FUSE mount missing st_birthtime, #4763 #4767
  * check: do not stumble over invalid item key, #4845
  * info: if the archive doesn't exist, print a pretty message, #4793
  * SecurityManager.known(): check all files, #4614
  * Repository.open: use stat() to check for repo dir, #4695
  * Repository.check_can_create_repository: use stat() to check, #4695
  * fix invalid archive error message
  * fix optional/non-optional location arg, #4541
  * commit-time free space calc: ignore bad compact map entries, #4796
  * ignore EACCES (errno 13) when hardlinking the old config, #4730
  * --prefix / -P: fix processing, avoid argparse issue, #4769
  New features:
  * enable placeholder usage in all extra archive arguments
  * new BORG_WORKAROUNDS mechanism, basesyncfile, #4710
  * recreate: support --timestamp option, #4745
  * support platforms without os.link (e.g. Android with Termux), #4901 if
    we don't have os.link, we just extract another copy instead of making a
    hardlink.
  * support linux platforms without sync_file_range (e.g. Android 7 with
    Termux), #4905
  Other:
  * ignore --stats when given with --dry-run, but continue, #4373
  * add some ProgressIndicator msgids to code / fix docs, #4935
  * elaborate on "Calculating size" message
  * argparser: always use REPOSITORY in metavar, also use more consistent
    help phrasing.
  * check: improve error output for matching index size, see #4829
* Wed Mar 11 2020 Paolo Stivanin <info@paolostivanin.com>
- fix building with python3
* Thu Oct 31 2019 Antonio Larrosa <alarrosa@suse.com>
- Require python3-setuptools since it's needed when running borg
  to find the entry point (boo#1134650)
* Thu May 23 2019 Hans-Peter Jansen <hpj@urpla.net>
- Update to version 1.1.10 (2019-05-16)
  + Compatibility notes:
  * When upgrading from borg 1.0.x to 1.1.x, please note:
  * read all the compatibility notes for 1.1.0*, starting from
    1.1.0b1.
  * borg upgrade: you do not need to and you also should not run
    it.
  * borg might ask some security-related questions once after
    upgrading. You can answer them either manually or via
    environment variable. One known case is if you use
    unencrypted repositories, then it will ask about a unknown
    unencrypted repository one time.
  * your first backup with 1.1.x might be significantly slower
    (it might completely read, chunk, hash a lot files) - this is
    due to the --files-cache mode change (and happens every time
    you change mode). You can avoid the one-time slowdown by
    using the pre-1.1.0rc4-compatible mode (but that is less safe
    for detecting changed files than the default). See the
  - -files-cache docs for details.
  + Fixes:
  * extract: hang on partial extraction with ssh: repo, when
    hardlink master is not matched/extracted and borg hangs on
    related slave hardlink, #4350
  * lrucache: regularly remove old FDs, #4427
  * avoid stale filehandle issues, #3265
  * freebsd: make xattr platform code api compatible with linux,
    [#3952]
  * use whitelist approach for borg serve, #4097
  * borg command shall terminate with rc 2 for ImportErrors,
    [#4424]
  * create: only run stat_simple_attrs() once, this increases
    backup with lots of unchanged files performance by ~ 5%%.
  * prune: fix incorrect borg prune --stats output with --dry-
    run, #4373
  * key export: emit user-friendly error if repo key is exported
    to a directory, #4348
  + New features:
  * bundle latest supported msgpack-python release (0.5.6),
    remove msgpack-python from setup.py install_requires - by
    default we use the bundled code now. optionally, we still
    support using an external msgpack (see hints in setup.py),
    but this requires solid requirements management within
    distributions and is not recommended. borgbackup will break
    if you upgrade msgpack to an unsupported version.
  * display msgpack version as part of sysinfo (e.g. in
    tracebacks)
  * timestamp for borg delete --info added, #4359
  * enable placeholder usage in --comment and --glob-archives,
    [#4559], #4495
  + Other:
  * serve: do not check python/libc for borg serve, #4483
  * shell completions: borg diff second archive
  * release scripts: signing binaries with Qubes OS support
  * testing:
  * vagrant: upgrade openbsd box to 6.4
  * travis-ci: lock test env to py 3.4 compatible versions, #4343
  * get rid of confusing coverage warning, #2069
  * rename test_mount_hardlinks to test_fuse_mount_hardlinks, so
    both can be excluded by "not test_fuse".
  * pure-py msgpack warning shall not make a lot of tests fail,
    [#4558]
  * docs:
  * add "SSH Configuration" section to "borg serve", #3988, #636,
    [#4485]
  * README: new URL for funding options
  * add a sample logging.conf in docs/misc, #4380
  * elaborate on append-only mode docs, #3504
  * installation: added Alpine Linux to distribution list, #4415
  * usage.html: only modify window.location when redirecting,
    [#4133]
  * add msgpack license to docs/3rd_party/msgpack
  * vagrant / binary builds:
  * use python 3.5.7 for builds
  * use osxfuse 3.8.3
- remove msgpack patch fix-msgpack-requirement.patch and borg_msgpack
  build conditional, since msgpack is bundled now (yeah!)
* Fri Mar  8 2019 Hans-Peter Jansen <hpj@urpla.net>
- According to upstream preference and dealing with msgpack update
  in Factory, allow msgpack <= 0.6.1 as well
* Tue Feb 12 2019 Hans-Peter Jansen <hpj@urpla.net>
- Modify patch fix-msgpack-requirement.patch to allow msgpack-0.5.4
  as well. See patch for discussion.
- Clean-up dependency blocks
* Mon Feb 11 2019 Jan Engelhardt <jengelh@inai.de>
- Update RPM groups.
* Mon Feb 11 2019 Antonio Larrosa <alarrosa@suse.com>
- Update to 1.1.9:
  - Fixes:
  - security fix: configure FUSE with "default_permissions",
    gh#borgbackup/borg#3903 "default_permissions" is now enforced by borg by
    default to let the kernel check uid/gid/mode based permissions.
    "ignore_permissions" can be given to not enforce "default_permissions".
  - make “hostname” short, even on misconfigured systems,
    gh#borgbackup/borg#4262
  - fix free space calculation on macOS (and others?),
    gh#borgbackup/borg#4289
  - config: quit with error message when no key is provided,
    gh#borgbackup/borg#4223
  - recover_segment: handle too small segment files correctly,
    gh#borgbackup/borg#4272
  - correctly release memoryview, gh#borgbackup/borg#4243
  - avoid diaper pattern in configparser by opening files,
    gh#borgbackup/borg#4263
  - add "# cython: language_level=3" directive to .pyx
    files, #4214
  - info: consider part files for "This archive" stats,
    gh#borgbackup/borg#3522
  - work around Microsoft WSL issue gh#borgbackup/borg#645 (sync_file_range),
    [#1961]
  - New features:
  - add –rsh command line option to complement BORG_RSH env var,
    gh#borgbackup/borg#1701
  - init: -make-parent-dirs parent1/parent2/repo_dir, gh#borgbackup/borg#4235
  - Other:
  - add archive name to check -repair output, gh#borgbackup/borg#3447
  - check for unsupported msgpack versions
  - shell completions:
  - new shell completions for borg 1.1.9
  - more complete shell completions for borg mount -o
  - added shell completions for borg help
  - option arguments for zsh tab completion
  - docs:
  - add FAQ regarding free disk space check, gh#borgbackup/borg#3905
  - update BORG_PASSCOMMAND example and clarify variable expansion,
    gh#borgbackup/borg#4249
  - FAQ regarding change of compression settings, gh#borgbackup/borg#4222
  - add note about BSD flags to changelog, gh#borgbackup/borg#4246
  - improve logging in example automation script
  - add note about files changing during backup, gh#borgbackup/borg#4081
  - work around the backslash issue, gh#borgbackup/borg#4280
  - update release workflow using twine (docs, scripts),
    gh#borgbackup/borg#4213
  - add warnings on repository copies to avoid future problems,
    gh#borgbackup/borg#4272
  - tests:
  - fix the homebrew 1.9 issues on travis-ci, gh#borgbackup/borg#4254
  - fix duplicate test method name, gh#borgbackup/borg#4311
- Moved the docs to a new -doc subpackage
- Use the %%license tag for the license
* Sun Feb  3 2019 Hans-Peter Jansen <hpj@urpla.net>
- Add conditionals to control various build aspects distribution
  agnostic
* Mon Dec 10 2018 atoptsoglou@suse.com
- Update to 1.1.8:
  - Fixes
  - enforce storage quota if set by serve-command
  - invalid locations: give err msg containing parsed location
  - list repo: add placeholders for hostname and username
  - symlinks can't have ACLs, so don't try to set any
  - New features
  - create: added PATH::archive output on INFO log level
  - read a passphrase from a file descriptor specified in the BORG_PASSPHRASE_FD environment variable.
  - docs:
  - option --format is required for some expensive-to-compute values for json
  - borg list by default does not compute expensive values except when they
    are needed. whether they are needed is determined by the format, in
    standard mode as well as in --json mode.
  - fixed wrong archive name pattern in CRUD benchmark help
  - fixed link to cachedir spec in docs
  - tests:
  - stop using fakeroot on travis, avoids sporadic EISDIR errors
  - xattr key names must start with "user." on linux
  - fix code so flake8 3.6 does not complain
  - explicitly convert environment variable to str
  - fix DeprecationWarning: Flags not at the start of the expression
  - support pytest4
* Sat Aug 11 2018 kbabioch@suse.com
- Update to 1.1.7:
  - Fixes
  - cache lock: use lock_wait everywhere to fix infinite wait
  - don't archive tagged dir when recursing an excluded dir
  - New features
  - init: add warning to store both key and passphrase at safe place(s)
  - BORG_HOST_ID env var to work around all-zero MAC address issue
  - borg debug dump-repo-objs --ghost (dump everything from segment files,
    including deleted or superceded objects or commit tags)
  - borg debug search-repo-objs (search in repo objects for hex bytes or strings)
  - Other changes:
  - add Python 3.7 support
  - updated shell completions
  - locking: better logging, add some asserts
* Mon Jun 11 2018 kbabioch@suse.com
- Update to 1.1.6:
  - Fixes
  - fix borg exception handling on ENOSPC error with xattrs
  - prune: fix/improve overall progress display
  - borg config repo ... does not need cache/manifest/key
  - New features
  - mount: add uid, gid, umask mount options
  - delete:
  - only commit once
  - implement --dry-run
  - check:
  - show progress while rebuilding missing manifest
  - more --repair output
  - borg config --list <repo>
* Wed May 23 2018 kbabioch@suse.com
- Use OpenPGP signature provided upstream
- Added borgbackup.keyring, which contains the key from the author
* Wed May  2 2018 mlin@suse.com
- Leap 15.0 and SLE15 both are moved to renamed python3-msgpack,
  fix-msgpack-requirement.patch have to be used to deal with msgpack
  package rename fallout.
* Mon Apr  2 2018 alarrosa@suse.com
- Update to 1.1.5
- Fixes:
  * create --list: fix that it was never showing M status
  * create: fix timing for first checkpoint (read files cache early,
    init checkpoint timer after that)
  * extract: set rc=1 when extracting damaged files with all-zero replacement
    chunks or with size inconsistencies
  * diff: consider an empty file as different to a non-existing file
  * files cache: improve exception handling
  * ignore exceptions in scandir_inorder() caused by an implicit stat(), also
    remove unneeded sort
  * fixed tab completion problem where a space is always added after path even
    when it shouldn't
  * build: do .h file content checks in binary mode, fixes build issue for
    non-ascii header files on pure-ascii locale platforms
  * borgfs: fix patterns/paths processing
  * config: add some validation
  * repository config: add validation for max_segment_size
  * set cache previous_location on load instead of save
  * remove platform.uname() call which caused library mismatch issues
  * add exception handler around deprecated platform.linux_distribution() call
  * use same datetime object for {now} and {utcnow}
- New features:
  * create: implement --stdin-name
  * add chunker_params to borg archive info (--json)
  * BORG_SHOW_SYSINFO=no to hide system information from exceptions
- Other changes:
  * updated zsh completions for borg 1.1.4
  * files cache related code cleanups
  * be more helpful when parsing invalid --pattern values
  * be more clear in secure-erase warning message
  * improve getpass user experience
  * docs build: unicode problem fixed when using a py27-based sphinx
- docs:
  * security: explicitly note what happens OUTSIDE the attack model
  * security: add note about combining compression and encryption
  * security: describe chunk size / proximity issue
  * quickstart: add note about permissions, borg@localhost
  * quickstart: add introduction to repositories & archives
  * recreate --recompress: add missing metavar, clarify description
  * improve logging docs
  * add an example for --pattern usage
  * clarify path semantics when matching
  * link to offline documentation from README
  * add docs on how to verify a signed release with GPG
  * chunk seed is generated per repository (not: archive)
  * better formatting of CPU usage documentation
  * extend append-only repo rollback docs
- tests:
  * fix erroneously skipped zstd compressor tests
  * skip a test if argparse is broken
- Drop borgbackup-1.1.4-binary-content-checks.patch which is already included
  upstream.
- Rebase fix-msgpack-requirement.patch
* Mon Mar  5 2018 hpj@urpla.net
- Fix sphinx theme fallback condition
* Sun Mar  4 2018 hpj@urpla.net
- Add patch to fall back to a sphinx default theme for older distributions
  that don't have python3-guzzle_sphinx_theme available
  * borgbackup-1.1.4-sphinx-default-theme.patch
* Thu Mar  1 2018 alarrosa@suse.com
- Add patch to require the new msgpack python module in Tumbleweed
  instead of the deprecated msgpack-python python module:
  * fix-msgpack-requirement.patch
* Tue Feb 27 2018 jacobwinski@gmail.com
- Add patch borgbackup-1.1.4-binary-content-checks.patch:
  * Fixes build failure due to bad encoding
  * Based on upstream commit 9cf8d57 "do .h file content checks in binary mode"
  * This patch will no longer be needed with borgbackup > 1.1.4
* Sun Jan 28 2018 alarrosa@suse.com
- Don't use liblz4 nor libzstd on Leap 42.x which doesn't support them
  and add missing requirement python-guzzle_sphinx_theme on Tumbleweed.
* Wed Jan 10 2018 alarrosa@suse.com
- Update to borgbackup 1.1.4
  * Fix a potential data corruption issue with 'borg check --repair'
    happening in borg >= 1.1 and < 1.1.4
  * zstd compression is new in borg 1.1.4, older borg can't handle it.
  * new minimum requirements for the compression libraries:
    + added requirement: libzstd >= 1.3.0
    + updated requirement: liblz4 >= 1.7.0 / r129
- Fixes:
  * check: data corruption fix: fix for borg check --repair malfunction. See
  the more detailed notes at
  https://github.com/borgbackup/borg/blob/1.1.4/docs/changes.rst
  * delete: also delete security dir when deleting a repo
  * prune: fix building the "borg prune" man page
  * init: use given --storage-quota for local repo
  * init: properly quote repo path in output
  * fix startup delay with dns-only own fqdn resolving
- New features:
  * added zstd compression.
  * added placeholder {reverse-fqdn} for fqdn in reverse notation
  * added BORG_BASE_DIR environment variable
- Other changes:
  * list help topics when invalid topic is requested
  * fix lz4 deprecation warning, requires lz4 >= 1.7.0 (r129)
  * add parens for C preprocessor macro argument usages (did not cause
    malfunction)
  * exclude broken pytest 3.3.0 release
  * updated fish/bash completions
  * init: more clear exception messages for borg create
  * docs:
    + add auto-generated docs for borg config
    + don't generate HTML docs page for borgfs
    + docs update for lz4 b2 zstd changes
    + add zstd to compression help, readme, docs
    + update requirements and install docs about bundled lz4 and zstd
    + refactored build of the compress and crypto.low_level extensions
    + move some lib/build related code to setup_{zstd,lz4,b2}.py
    + bundle lz4 1.8.0 (requirement: >= 1.7.0 / r129)
    + bundle zstd 1.3.2 (requirement: >= 1.3.0)
    + blake2 was already bundled
    + rename BORG_LZ4_PREFIX env var to BORG_LIBLZ4_PREFIX for better
    consistency: we also have BORG_LIBB2_PREFIX and BORG_LIBZSTD_PREFIX now.
    + add prefer_system_lib* = True settings to setup.py - by default the
    build will prefer a shared library over the bundled code, if library
    and headers can be found and meet the minimum requirements.
* Mon Dec 11 2017 alarrosa@suse.com
- Update to borgbackup 1.1.3
- Fixes:
  * Security Fix for CVE-2017-15914: Incorrect implementation of access
    controls allows remote users to override repository restrictions in Borg
    servers. A user able to access a remote Borg SSH server is able to
    circumvent access controls post-authentication.
    Affected releases: 1.1.0, 1.1.1, 1.1.2. Releases 1.0.x are NOT affected.
  * crc32: deal with unaligned buffer, add tests - this broke borg on older ARM
    CPUs that can not deal with unaligned 32bit memory accesses and raise a bus
    error in such cases. the fix might also improve performance on some CPUs as
    all 32bit memory accesses by the crc32 code are properly aligned now.
  * mount: fixed support of --consider-part-files and do not show .borg_part_N
    files by default in the mounted FUSE filesystem.
  * fixed cache/repo timestamp inconsistency message, highlight that
    information is obtained from security dir (deleting the cache will not
    bypass this error in case the user knows this is a legitimate repo).
  * borgfs: don't show sub-command in borgfs help
  * create: show an error when --dry-run and --stats are used together
- New features:
  * mount: added exclusion group options and paths.
    Reused some code to support similar options/paths as borg extract offers -
    making good use of these to only mount a smaller subset of dirs/files can
    speed up mounting a lot and also will consume way less memory.
    borg mount [options] repo_or_archive mountpoint path [paths...]
    paths: you can just give some "root paths" (like for borg extract) to only
    partially populate the FUSE filesystem.
    new options: --exclude[-from], --pattern[s-from], --strip-components
  * create/extract: support st_birthtime on platforms supporting it
  * add "borg config" command for querying/setting/deleting config values
- Other changes:
  * clean up and simplify packaging (only package committed files,
  do not install .c/.h/.pyx files)
  * docs:
  * point out tuning options for borg create
  * add instructions for using ntfsclone, zerofree
  * move image backup-related FAQ entries to a new page
  * clarify key aliases for borg list --format
  * mention break-lock in checkpointing FAQ entry
  * document sshfs rename workaround
  * add FAQ about removing files from existing archives
  * add FAQ about different prune policies
  * usage and man page for borgfs
  * clarify create --stats duration vs. wall time
  * clarify encrypted key format for borg key export
  * update release checklist about security fixes
  * document good and problematic option placements, fix examples
  * add note on using --nobsdflags to avoid speed penalty related to bsdflags
  * move most of support section to www.borgbackup.org
* Fri Nov 10 2017 alarrosa@suse.com
- Fix build on Leap 42.2 by BuildRequiring bash-completion
* Wed Nov  8 2017 alarrosa@suse.com
- Update to borgbackup 1.1.2
- Fixes:
  * fix KeyError crash when talking to borg server < 1.0.7
  * extract: set bsdflags last (include immutable flag)
  * create: don't do stat() call on excluded-norecurse directory, fix exception handling for stat() call
  * create --stats: do not count data volume twice when checkpointing
  * recreate: move chunks_healthy when excluding hardlink master
  * recreate: get rid of chunks_healthy when rechunking (does not match)
  * check: get rid of already existing not matching chunks_healthy metadata
  * list: fix stdout broken pipe handling
  * list/diff: remove tag-file options (not used)
- New features:
  * bash, zsh and fish shell auto-completions, see scripts/shell_completions/
  * added BORG_CONFIG_DIR env var
- Other changes:
  * docs:
  * clarify using a blank passphrase in keyfile mode
  * mention "!" (exclude-norecurse) type in "patterns" help
  * document to first heal before running borg recreate to re-chunk stuff, because that will have to get rid of chunks_healthy metadata.
  * more than 23 is not supported for CHUNK_MAX_EXP
  * borg does not respect nodump flag by default any more
  * clarify same-filesystem requirement for borg upgrade
  * update / rephrase cygwin / WSL status
  * improve docs about --stats
  * vagrant: openindiana new clang package
- Already contained in 1.1.1 (last minute fix):
  * arg parsing: fix fallback function, refactor
- Generate new subpackages borgbackup-bash-completion,
  borgbackup-zsh-completion and borgbackup-fish-completion with
  autocompletion scripts for each shell.
* Mon Oct 23 2017 alarrosa@suse.com
- Update to borgbackup 1.1.1
- Compatibility notes:
  * When upgrading from borg 1.0.x to 1.1.x, please note:
  * read all the compatibility notes for 1.1.0*, starting from 1.1.0b1.
  * borg might ask some security-related questions once after upgrading.
    You can answer them either manually or via environment variable.
    One known case is if you use unencrypted repositories, then it will ask
    about a unknown unencrypted repository one time.
  * your first backup with 1.1.x might be significantly slower (it might
    completely read, chunk, hash a lot files) - this is due to the
  - -files-cache mode change (and happens every time you change mode). You
    can avoid the one-time slowdown by using the pre-1.1.0rc4-compatible mode
    (but that is less safe for detecting changed files than the default).
    See the --files-cache docs for details.
  * The deprecated --no-files-cache is not a global/common option any more, but
    only available for borg create (it is not needed for anything else).
    Use --files-cache=disabled instead of --no-files-cache.
  * The nodump flag ("do not backup this file") is not honoured any more by
    default because this functionality (esp. if it happened by error or
    unexpected) was rather confusing and unexplainable at first to users.
    If you want that "do not backup NODUMP-flagged files" behaviour, use:
    borg create --exclude-nodump ...
- Fixes:
  * borg recreate: correctly compute part file sizes. fixes cosmetic, but
    annoying issue as borg check complains about size inconsistencies of part
    files in affected archives. you can solve that by running borg recreate
    on these archives.
  * bsdflags support: do not open BLK/CHR/LNK files, avoid crashes and slowness
  * recreate: don't crash on attic archives w/o time_end
  * don't crash on repository filesystems w/o hardlink support
  * don't crash in first part of truncate_and_unlink
  * fix server-side IndexError crash with clients < 1.0.7
  * don't show traceback if only a global option is given, show help
  * cache: use SaveFile for more safety
  * init: fix wrong encryption choices in command line parser, fix missing
    "authenticated-blake2"
  * move --no-files-cache from common to borg create options
  * fix detection of non-local path (failed on ..filename)
  * logging with fileConfig: set json attr on "borg" logger
  * fix crash with relative BORG_KEY_FILE
  * show excluded dir with "x" for tagged dirs / caches
- New features:
  * create: --nobsdflags and --exclude-nodump options
  * extract: --nobsdflags option
- Other changes:
  * remove annoying hardlinked symlinks warning
  * vagrant: use self-made FreeBSD 10.3 box
  * docs:
  * readme: -e option is required in borg 1.1
  * add example showing --show-version --show-rc
  * use --format rather than --list-format (deprecated) in example
  * update docs about hardlinked symlinks limitation
* Sun Oct  8 2017 alarrosa@suse.com
- Update to borgbackup 1.1.0
- Changelog:
  * Major new features in the 1.1 release series are:
  * borg recreate: remove files from existing archives and re-chunk or
    re-compress them. This finally allows deduplication between legacy
    Attic / Borg 0.xx archives and Borg 1.x archives. This is an
    experimental feature.
  * borg diff: show differences between two archives.
  * borg mount: show all recorded versions of files with the "versions view".
  * borg list: more formatting options, including generation of hashes and
    per-file chunk statistics.
  * borg create: automatic compression mode (-C auto,zlib/lz4/...), faster
    handling of many files, experimental support for inclusion patterns
    (--patterns, --patterns-from), files cache mode control (mtime/ctime)
  * borg export-tar: streaming export of GNU tar compatible archives.
  * Archive comments
  * BLAKE2b256-based encryption modes, and "authenticated" modes that provide
    data integrity without encryption. These provide better performance than
    the existing SHA-256-based modes on most hardware, except where the x86
    SHA extensions are available (e.g. AMD Ryzen).
  * Repository indices and the Borg cache now use checksums to detect bitrot
    and other corruption.
  * A documented JSON API has been added to the most vital commands
    (borg list, borg info and borg create).
  * Structured JSON logging is available for all commands.
  * --prefix has been supplemented with --glob-archives (-a), --sort-by,
  - -last and --first options. These can be used for borg list, borg info,
    borg mount, borg check, borg delete and borg prune.
  * Quality of life improvements:
  * options that imply output (--show-rc, --show-version, --list, --stats,
  - -progress) don't need -v/--info to have that output displayed any more.
  * borg check is silent by default (finally!).
  * borg can now checkpoint within (big) files, not only between files.
  * borg delete can delete multiple archives by giving their names.
  * Automatic removal of stale locks, which should make "borg break-lock"
    essentially superfluous. This is enabled by default, see
    BORG_HOSTNAME_IS_UNIQUE.
  * Answers to prompts like "Accessing previously unknown repository" are
    now saved immediately.
  * Cache synchronization and "borg info" are now faster.
  * Reduced space usage of chunks.archive.d in the cache by 30-40 %%.
    Existing caches are migrated during a cache sync.
  * The cache used for remote cache syncs and mounting remote repositories
    does not grow indefinitely any more, but adapts to the available space.
    Good riddance, TMP=/var/tmp!
  * BORG_PASSCOMMAND makes using key rings and hardware keys much easier.
  * Documentation improvements
  * Compatibility notes for upgrading from Borg 1.0 to Borg 1.1:
  * No explicit "borg upgrade" is required.
  * Borg 1.1 uses some new data structures which are backwards-compatible
    with Borg 1.0.4 and newer.
  * Borg 1.0 can't make use of Borg 1.1's "compact cache" and will
    silently ignore it.
  * The default compression has been changed from "none" to "lz4".
  * Repositories in the "repokey" and "repokey-blake2" modes with an empty
    passphrase are now treated as unencrypted repositories for security
    checks (e.g. BORG_UNKNOWN_UNENCRYPTED_REPO_ACCESS_IS_OK).
  * borg init:
    + -e/--encryption is now a mandatory option with no default value.
    Previously the default value was "repokey".
    + the short form of --append-only (-a) has been removed.
    + running "borg init" via a "borg serve --append-only" server will not
    create an append-only repository any more.
    Use "borg init --append-only" to initialize an append-only repository.
  * borg create: the --exclude-if-present option now supports tagging a
    folder with any file system object type (file, folder, etc.), instead of
    accepting only files as tags.
  * borg upgrade: the short form of --inplace (-i) has been removed.
  * borg delete: the short form of --cache-only (-c) has been removed.
  * "borg migrate-to-repokey" has been renamed to
    "borg key migrate-to-repokey" with no deprecation notice, since it is
    rarely and only manually used.
- For more information, see https://www.borgbackup.org/releases/borg-1.1.html
* Wed Aug  2 2017 lbeltrame@kde.org
- Update to version 1.0.11 (2017-07-21)
  Bug fixes:
  - use limited unpacker for outer key (security precaution), #2174
  - fix paperkey import bug
  Other changes:
  - change --checkpoint-interval default from 600s to 1800s, #2841.
    this improves efficiency for big repositories a lot.
  - docs: fix OpenSUSE command and add OpenSUSE section
  - tests: add tests for split_lstring and paperkey
  - vagrant:
  - fix openbsd shell
  - backport cpu/ram setup from master
  - add stretch64 VM
* Sun May  7 2017 hpj@urpla.net
- update to version 1.0.10 (2017-02-13)
  Bug fixes:
  - Manifest timestamps are now monotonically increasing, this fixes
    issues when the system clock jumps backwards or is set inconsistently
    across computers accessing the same repository, #2115
  - Fixed testing regression in 1.0.10rc1 that lead to a hard dependency
    on py.test >= 3.0, #2112
  New features:
  - “key export” can now generate a printable HTML page with both a QR
    code and a human-readable “paperkey” representation (and custom text)
    through the --qr-html option.
  - The same functionality is also available through paperkey.html, which
    is the same HTML page generated by --qr-html. It works with existing
    “key export” files and key files.
  Other changes:
  - docs:
  - language clarification - “borg create –one-file-system” option
    does not respect mount points, but considers different file systems
    instead, #2141
  - setup.py: build_api: sort file list for determinism
- update to version 1.0.10rc1 (2017-01-29)
  Bug fixes:
  - borg serve: fix transmission data loss of pipe writes, #1268 This
    affects only the cygwin platform (not Linux, BSD, OS X).
  - Avoid triggering an ObjectiveFS bug in xattr retrieval, #1992
  - When running out of buffer memory when reading xattrs, only skip the
    current file, #1993
  - Fixed “borg upgrade –tam” crashing with unencrypted repositories. Since
    the issue is not relevant for unencrypted repositories, it now does
    nothing and prints an error, #1981.
  - Fixed change-passphrase crashing with unencrypted repositories, #1978
  - Fixed “borg check repo::archive” indicating success if “archive” does
    not exist, #1997
  - borg check: print non-exit-code warning if –last or –prefix aren’t
    fulfilled
  - fix bad parsing of wrong repo location syntax
  - create: don’t create hard link refs to failed files, mount: handle
    invalid hard link refs, #2092
  - detect mingw byte order, #2073
  - creating a new segment: use “xb” mode, #2099
  - mount: umount on SIGINT/^C when in foreground, #2082
  Other changes:
  - binary: use fixed AND freshly compiled pyinstaller bootloader, #2002
  - xattr: ignore empty names returned by llistxattr(2) et al
  - Enable the fault handler: install handlers for the SIGSEGV, SIGFPE,
    SIGABRT, SIGBUS and SIGILL signals to dump the Python traceback.
  - Also print a traceback on SIGUSR2.
  - borg change-passphrase: print key location (simplify making a backup
    of it)
  - officially support Python 3.6 (setup.py: add Python 3.6 qualifier)
    tests:
  - vagrant / travis / tox: add Python 3.6 based testing
  - vagrant: fix openbsd repo, #2042
  - vagrant: fix the freebsd64 machine, #2037 #2067
  - vagrant: use python 3.5.3 to build binaries, #2078
  - vagrant: use osxfuse 3.5.4 for tests / to build binaries vagrant:
    improve darwin64 VM settings
  - travis: fix osxfuse install (fixes OS X testing on Travis CI)
  - travis: require succeeding OS X tests, #2028
  - travis: use latest pythons for OS X based testing
  - use pytest-xdist to parallelize testing
  - fix xattr test race condition, #2047
  - setup.cfg: fix pytest deprecation warning, #2050
    docs:
  - language clarification - VM backup FAQ
  - borg create: document how to backup stdin, #2013
  - borg upgrade: fix incorrect title levels
  - add CVE numbers for issues fixed in 1.0.9, #2106
  - fix typos (taken from Debian package patch)
  - remote: include data hexdump in “unexpected RPC data” error message
  - remote: log SSH command line at debug level
  - API_VERSION: use numberspaces, #2023
  - remove .github from pypi package, #2051
  - add pip and setuptools to requirements file, #2030
  - SyncFile: fix use of fd object after close (cosmetic)
  - Manifest.in: simplify, exclude *.{so,dll,orig}, #2066
  - ignore posix_fadvise errors in repository.py, #2095 (works around
    issues with docker on ARM)
  - make LoggedIO.close_segment reentrant, avoid reentrance
* Tue Jan  3 2017 hpj@urpla.net
- disable %%check for leap versions, their pytest package is too old
* Tue Jan  3 2017 hpj@urpla.net
- update to version 1.0.9 (2016-12-20)
  - Security fixes:
  - A flaw in the cryptographic authentication scheme in Borg allowed
    an attacker to spoof the manifest. See :ref:`tam_vuln` above for
    the steps you should take.
    Fixes CVE-2016-10099
  - borg check: When rebuilding the manifest (which should only be
    needed very rarely) duplicate archive names would be handled on a
    "first come first serve" basis, allowing an attacker to apparently
    replace archives.
    Fixes CVE-2016-10100
  - Bug fixes:
  - borg check:
    rebuild manifest if it's corrupted
    skip corrupted chunks during manifest rebuild
  - fix TypeError in integrity error handler, #1903, #1894
  - fix location parser for archives with @ char (regression introduced
    in 1.0.8), #1930
  - fix wrong duration/timestamps if system clock jumped during a create
  - fix progress display not updating if system clock jumps backwards
  - fix checkpoint interval being incorrect if system clock jumps
- update to version 1.0.9rc1 (2016-11-27)
  - Bug fixes:
  - files cache: fix determination of newest mtime in backup set (which
    is used in cache cleanup and led to wrong "A" [added] status for
    unchanged files in next backup), #1860.
  - borg check:
  - fix incorrectly reporting attic 0.13 and earlier archives as corrupt
  - handle repo w/o objects gracefully and also bail out early if repo
    is completely empty, #1815.
  - fix tox/pybuild in 1.0-maint
  - at xattr module import time, loggers are not initialized yet
- update to version 1.0.8 (2016-10-29)
  - Bug fixes:
  - RemoteRepository: Fix busy wait in call_many, #940
- update to version 1.0.8rc1 (2016-10-17)
  - Bug fixes:
  - fix signal handling (SIGINT, SIGTERM, SIGHUP), #1620 #1593 Fixes e.g.
    leftover lock files for quickly repeated signals (e.g. Ctrl-C Ctrl-C)
    or lost connections or systemd sending SIGHUP.
  - progress display: adapt formatting to narrow screens, do not crash,
    [#1628]
  - borg create --read-special - fix crash on broken symlink, #1584. also
    correctly processes broken symlinks. before this regressed to a crash
    (5b45385) a broken symlink would've been skipped.
  - process_symlink: fix missing backup_io() Fixes a chmod/chown/chgrp/
    unlink/rename/... crash race between getting dirents and dispatching
    to process_symlink.
  - yes(): abort on wrong answers, saying so, #1622
  - fixed exception borg serve raised when connection was closed before
    reposiory was openend. add an error message for this.
  - fix read-from-closed-FD issue, #1551 (this seems not to get triggered
    in 1.0.x, but was discovered in master)
  - hashindex: fix iterators (always raise StopIteration when exhausted)
    (this seems not to get triggered in 1.0.x, but was discovered in master)
  - enable relative pathes in ssh:// repo URLs, via /./relpath hack, #1655
  - allow repo pathes with colons, #1705
  - update changed repo location immediately after acceptance, #1524
  - fix debug get-obj / delete-obj crash if object not found and remote
    repo, #1684
  - pyinstaller: use a spec file to build borg.exe binary, exclude osxfuse
    dylib on Mac OS X (avoids mismatch lib <-> driver), #1619
* Sun Oct 30 2016 jengelh@inai.de
- Trim description
* Thu Oct 13 2016 alarrosa@suse.com
- Remove smp parameters when building documentation so different
  sphinx instances are not run in parallel which sometimes fails
  due to a race condition
* Sat Aug 20 2016 hpj@urpla.net
- update to version 1.0.7 (2016-08-19):
  a critical security fix and some major bug fixes
  Please check:
  https://github.com/borgbackup/borg/blob/1.0.7/docs/changes.rst
- clean specfile
* Sat Jul 16 2016 hpj@urpla.net
- update to version 1.0.6 (2016-07-12)
  Bug fixes:
  * Linux: handle multiple LD_PRELOAD entries correctly, #1314, #1111
  * Fix crash with unclear message if the libc is not found, #1314, #1111
  Other changes:
  * tests:
  * Fixed O_NOATIME tests for Solaris and GNU Hurd, #1315
  * Fixed sparse file tests for (file) systems not supporting it, #1310
  * docs:
  * Fixed syntax highlighting, #1313
  * misc docs: added data processing overview picture
- update to version 1.0.6rc1 (2016-07-10)
  New features:
  * borg check –repair: heal damaged files if missing chunks re-appear (e.g. if the
    previously missing chunk was added again in a later backup archive), #148. (*)
    Also improved logging.
  Bug fixes:
  * sync_dir: silence fsync() failing with EINVAL, #1287 Some network filesystems
    (like smbfs) don’t support this and we use this in repository code.
  * borg mount (FUSE):
    fix directories being shadowed when contained paths were also specified, #1295
    raise I/O Error (EIO) on damaged files (unless -o allow_damaged_files is used),
    [#1302]. (*)
  * borg extract: warn if a damaged file is extracted, #1299. (*)
    Added some missing return code checks (ChunkIndex._add, hashindex_resize).
  * borg check: fix/optimize initial hash table size, avoids resize of the table.
  Other changes:
  * tests:
    add more FUSE tests, #1284
    deduplicate fuse (u)mount code
    fix borg binary test issues, #862
  * docs:
    changelog: added release dates to older borg releases
    fix some sphinx (docs generator) warnings, #881
  Notes:
  (*) Some features depend on information (chunks_healthy list) added to item metadata
    when a file with missing chunks was “repaired” using all-zero replacement chunks.
    The chunks_healthy list is generated since borg 1.0.4, thus borg can’t recognize
    such “repaired” (but content-damaged) files if the repair was done with an older
    borg version.
- update to version 1.0.5 (2016-07-07)
  Bug fixes:
  * borg mount: fix FUSE crash in xattr code on Linux introduced in 1.0.4, #1282
  Other changes:
  * backport some FAQ entries from master branch
  * add release helper scripts
  * Vagrantfile:
    centos6: no FUSE, don’t build binary
    add xz for redhat-like dists
- update to version 1.0.4 (2016-07-07)
  New features:
  * borg serve –append-only, #1168 This was included because it was a simple change
    (append-only functionality was already present via repository config file) and makes
    better security now practically usable.
  * BORG_REMOTE_PATH environment variable, #1258 This was included because it was a simple
    change (–remote-path cli option was already present) and makes borg much easier to use
    if you need it.
  * Repository: cleanup incomplete transaction on “no space left” condition. In many cases,
    this can avoid a 100%% full repo filesystem (which is very problematic as borg always
    needs free space - even to delete archives).
  Bug fixes:
  * Fix wrong handling and reporting of OSErrors in borg create, #1138. This was a serious
    issue: in the context of “borg create”, errors like repository I/O errors (e.g. disk
    I/O errors, ssh repo connection errors) were handled badly and did not lead to a crash
    (which would be good for this case, because the repo transaction would be incomplete and
    trigger a transaction rollback to clean up). Now, error handling for source files is
    cleanly separated from every other error handling, so only problematic input files are
    logged and skipped.
  * Implement fail-safe error handling for borg extract. Note that this isn’t nearly as
    critical as the borg create error handling bug, since nothing is written to the repo.
    So this was “merely” misleading error reporting.
  * Add missing error handler in directory attr restore loop.
  * repo: make sure write data hits disk before the commit tag (#1236) and also sync the
    containing directory.
  * FUSE: getxattr fail must use errno.ENOATTR, #1126 (fixes Mac OS X Finder malfunction:
    “zero bytes” file length, access denied)
  * borg check –repair: do not lose information about the good/original chunks. If we do not
    lose the original chunk IDs list when “repairing” a file (replacing missing chunks with
    all-zero chunks), we have a chance to “heal” the file back into its original state later,
    in case the chunks re-appear (e.g. in a fresh backup). Healing is not implemented yet,
    see #148.
  * fixes for –read-special mode:
    ignore known files cache, #1241
    fake regular file mode, #1214
    improve symlinks handling, #1215
  * remove passphrase from subprocess environment, #1105
  * Ignore empty index file (will trigger index rebuild), #1195
  * add missing placeholder support for –prefix, #1027
  * improve exception handling for placeholder replacement
  * catch and format exceptions in arg parsing
  * helpers: fix “undefined name ‘e’” in exception handler
  * better error handling for missing repo manifest, #1043
  * borg delete:
    make it possible to delete a repo without manifest
    borg delete –forced allows to delete corrupted archives, #1139
  * borg check:
    make borg check work for empty repo
    fix resync and msgpacked item qualifier, #1135
    rebuild_manifest: fix crash if ‘name’ or ‘time’ key were missing.
    better validation of item metadata dicts, #1130
    better validation of archive metadata dicts
  * close the repo on exit - even if rollback did not work, #1197. This is rather cosmetic,
    it avoids repo closing in the destructor.
  * tests:
    fix sparse file test, #1170
    flake8: ignore new F405, #1185
    catch “invalid argument” on cygwin, #257
    fix sparseness assertion in test prep, #1264
  Other changes:
  * make borg build/work on OpenSSL 1.0 and 1.1, #1187
  * docs / help:
    fix / clarify prune help, #1143
    fix “patterns” help formatting
    add missing docs / help about placeholders
    resources: rename atticmatic to borgmatic
    document sshd settings, #545
    more details about checkpoints, add split trick, #1171
    support docs: add freenode web chat link, #1175
    add prune visualization / example, #723
    add note that Fnmatch is default, #1247
    make clear that lzma levels > 6 are a waste of cpu cycles
    add a “do not edit” note to auto-generated files, #1250
    update cygwin installation docs
  * repository interoperability with borg master (1.1dev) branch:
    borg check: read item metadata keys from manifest, #1147
    read v2 hints files, #1235
    fix hints file “unknown version” error handling bug
  * tests: add tests for format_line
  * llfuse: update version requirement for freebsd
  * Vagrantfile:
    use openbsd 5.9, #716
    do not install llfuse on netbsd (broken)
    update OSXfuse to version 3.3.3
    use Python 3.5.2 to build the binaries
  * glibc compatibility checker: scripts/glibc_check.py
  * add .eggs to .gitignore
* Tue Jun 14 2016 hpj@urpla.net
- Update to version 1.0.3:
  Bug fixes:
  - prune: avoid that checkpoints are kept and completed archives are deleted
    in a prune run), #997
  - prune: fix commandline argument validation - some valid command lines were
    considered invalid (annoying, but harmless), #942
  - fix capabilities extraction on Linux (set xattrs last, after chown()), #1069
  - repository: fix commit tags being seen in data
  - when probing key files, do binary reads. avoids crash when non-borg binary
    files are located in borg's key files directory.
  - handle SIGTERM and make a clean exit - avoids orphan lock files.
  - repository cache: don't cache large objects (avoid using lots of temp. disk
    space), #1063
  Other changes:
  - Vagrantfile: OS X: update osxfuse / install lzma package, #933
  - setup.py: add check for platform_darwin.c
  - setup.py: on freebsd, use a llfuse release that builds ok
  - docs / help:
  - update readthedocs URLs, #991
  - add missing docs for "borg break-lock", #992
  - borg create help: add some words to about the archive name
  - borg create help: document format tags, #894
* Wed May 11 2016 hpj@urpla.net
- Update to version 1.0.2:
  Bug fixes:
  - fix malfunction and potential corruption on (nowadays rather rare)
    big-endian architectures or bi-endian archs in (rare) BE mode. #886, #889
    cache resync / index merge was malfunctioning due to this, potentially
    leading to data loss. borg info had cosmetic issues (displayed wrong values).
    note: all (widespread) little-endian archs (like x86/x64) or bi-endian
    archs in (widespread) LE mode (like ARMEL, MIPSEL, ...) were NOT affected.
  - add overflow and range checks for 1st (special) uint32 of the hashindex
    values, switch from int32 to uint32.
  - fix so that refcount will never overflow, but just stick to max. value after
    a overflow would have occured.
  - borg delete: fix --cache-only for broken caches, #874
    Makes --cache-only idempotent: it won't fail if the cache is already deleted.
  - fixed borg create --one-file-system erroneously traversing into other
    filesystems (if starting fs device number was 0), #873
  - workround a bug in Linux fadvise FADV_DONTNEED, #907
  Other changes:
  - better test coverage for hashindex, incl. overflow testing, checking correct
    computations so endianness issues would be discovered.
  - reproducible doc for ProgressIndicator*, make the build reproducible.
  - use latest llfuse for vagrant machines
  - docs:
  - use /path/to/repo in examples, fixes #901
  - fix confusing usage of "repo" as archive name (use "arch")
* Sun Apr 10 2016 hpj@urpla.net
- Update to version 1.0.1:
  New features:
  Usually there are no new features in a bugfix release, but these were added
  due to their high impact on security/safety/speed or because they are fixes
  also:
  - append-only mode for repositories, #809, #36 (see docs)
  - borg create: add --ignore-inode option to make borg detect unmodified files
    even if your filesystem does not have stable inode numbers (like sshfs and
    possibly CIFS).
  - add options --warning, --error, --critical for missing log levels, #826.
    it's not recommended to suppress warnings or errors, but the user may decide
    this on his own.
    note: --warning is not given to borg serve so a <= 1.0.0 borg will still
    work as server (it is not needed as it is the default).
    do not use --error or --critical when using a <= 1.0.0 borg server.
  Bug fixes:
  - fix silently skipping EIO, #748
  - add context manager for Repository (avoid orphan repository locks), #285
  - do not sleep for >60s while waiting for lock, #773
  - unpack file stats before passing to FUSE
  - fix build on illumos
  - don't try to backup doors or event ports (Solaris and derivates)
  - remove useless/misleading libc version display, #738
  - test suite: reset exit code of persistent archiver, #844
  - RemoteRepository: clean up pipe if remote open() fails
  - Remote: don't print tracebacks for Error exceptions handled downstream, #792
  - if BORG_PASSPHRASE is present but wrong, don't prompt for password, but fail
    instead, #791
  - ArchiveChecker: move "orphaned objects check skipped" to INFO log level, #826
  - fix capitalization, add ellipses, change log level to debug for 2 messages,
    [#798]
  Other changes:
  - update llfuse requirement, llfuse 1.0 works
  - update OS / dist packages on build machines, #717
  - prefer showing --info over -v in usage help, #859
  - docs:
  - fix cygwin requirements (gcc-g++)
  - document how to debug / file filesystem issues, #664
  - fix reproducible build of api docs
  - RTD theme: CSS !important overwrite, #727
  - Document logo font. Recreate logo png. Remove GIMP logo file.
- rename package to borgbackup
- create/install html docs/man page
- remove dependency on python3-pytest-benchmark
* Tue Apr  5 2016 hpj@urpla.net
- version 1.0.0: initial build
